# Security Policy

## Reporting a Vulnerability

If you have information about a security issue or vulnerability within openMTPK, please 
highlight the issue as well as version within a pull request, discussion, or send an e-mail 
to akiel@akiel.org.

Please provide as much information as possible:

- A detailed description of the vulnerability we can use to reproduce your findings.

- Who can exploit this vulnerability and what would they gain. An attack scenario.

- Information about known exploits if any.

A member of the Security Team will review your e-mail and contact you to collaborate on resolving the issue.
